# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: v1.11.2
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class V1beta1IngressBackend(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'service_name': 'str',
        'service_port': 'object'
    }

    attribute_map = {
        'service_name': 'serviceName',
        'service_port': 'servicePort'
    }

    def __init__(self, service_name=None, service_port=None):
        """
        V1beta1IngressBackend - a model defined in Swagger
        """

        self._service_name = None
        self._service_port = None
        self.discriminator = None

        self.service_name = service_name
        self.service_port = service_port

    @property
    def service_name(self):
        """
        Gets the service_name of this V1beta1IngressBackend.
        Specifies the name of the referenced service.

        :return: The service_name of this V1beta1IngressBackend.
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """
        Sets the service_name of this V1beta1IngressBackend.
        Specifies the name of the referenced service.

        :param service_name: The service_name of this V1beta1IngressBackend.
        :type: str
        """
        if service_name is None:
            raise ValueError("Invalid value for `service_name`, must not be `None`")

        self._service_name = service_name

    @property
    def service_port(self):
        """
        Gets the service_port of this V1beta1IngressBackend.
        Specifies the port of the referenced service.

        :return: The service_port of this V1beta1IngressBackend.
        :rtype: object
        """
        return self._service_port

    @service_port.setter
    def service_port(self, service_port):
        """
        Sets the service_port of this V1beta1IngressBackend.
        Specifies the port of the referenced service.

        :param service_port: The service_port of this V1beta1IngressBackend.
        :type: object
        """
        if service_port is None:
            raise ValueError("Invalid value for `service_port`, must not be `None`")

        self._service_port = service_port

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, V1beta1IngressBackend):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: v1.11.2
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class V1ControllerRevision(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'api_version': 'str',
        'data': 'RuntimeRawExtension',
        'kind': 'str',
        'metadata': 'V1ObjectMeta',
        'revision': 'int'
    }

    attribute_map = {
        'api_version': 'apiVersion',
        'data': 'data',
        'kind': 'kind',
        'metadata': 'metadata',
        'revision': 'revision'
    }

    def __init__(self, api_version=None, data=None, kind=None, metadata=None, revision=None):
        """
        V1ControllerRevision - a model defined in Swagger
        """

        self._api_version = None
        self._data = None
        self._kind = None
        self._metadata = None
        self._revision = None
        self.discriminator = None

        if api_version is not None:
          self.api_version = api_version
        if data is not None:
          self.data = data
        if kind is not None:
          self.kind = kind
        if metadata is not None:
          self.metadata = metadata
        self.revision = revision

    @property
    def api_version(self):
        """
        Gets the api_version of this V1ControllerRevision.
        APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#resources

        :return: The api_version of this V1ControllerRevision.
        :rtype: str
        """
        return self._api_version

    @api_version.setter
    def api_version(self, api_version):
        """
        Sets the api_version of this V1ControllerRevision.
        APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#resources

        :param api_version: The api_version of this V1ControllerRevision.
        :type: str
        """

        self._api_version = api_version

    @property
    def data(self):
        """
        Gets the data of this V1ControllerRevision.
        Data is the serialized representation of the state.

        :return: The data of this V1ControllerRevision.
        :rtype: RuntimeRawExtension
        """
        return self._data

    @data.setter
    def data(self, data):
        """
        Sets the data of this V1ControllerRevision.
        Data is the serialized representation of the state.

        :param data: The data of this V1ControllerRevision.
        :type: RuntimeRawExtension
        """

        self._data = data

    @property
    def kind(self):
        """
        Gets the kind of this V1ControllerRevision.
        Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#types-kinds

        :return: The kind of this V1ControllerRevision.
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """
        Sets the kind of this V1ControllerRevision.
        Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#types-kinds

        :param kind: The kind of this V1ControllerRevision.
        :type: str
        """

        self._kind = kind

    @property
    def metadata(self):
        """
        Gets the metadata of this V1ControllerRevision.
        Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata

        :return: The metadata of this V1ControllerRevision.
        :rtype: V1ObjectMeta
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this V1ControllerRevision.
        Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata

        :param metadata: The metadata of this V1ControllerRevision.
        :type: V1ObjectMeta
        """

        self._metadata = metadata

    @property
    def revision(self):
        """
        Gets the revision of this V1ControllerRevision.
        Revision indicates the revision of the state represented by Data.

        :return: The revision of this V1ControllerRevision.
        :rtype: int
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """
        Sets the revision of this V1ControllerRevision.
        Revision indicates the revision of the state represented by Data.

        :param revision: The revision of this V1ControllerRevision.
        :type: int
        """
        if revision is None:
            raise ValueError("Invalid value for `revision`, must not be `None`")

        self._revision = revision

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, V1ControllerRevision):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: v1.11.2
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class V1EventSeries(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'count': 'int',
        'last_observed_time': 'datetime',
        'state': 'str'
    }

    attribute_map = {
        'count': 'count',
        'last_observed_time': 'lastObservedTime',
        'state': 'state'
    }

    def __init__(self, count=None, last_observed_time=None, state=None):
        """
        V1EventSeries - a model defined in Swagger
        """

        self._count = None
        self._last_observed_time = None
        self._state = None
        self.discriminator = None

        if count is not None:
          self.count = count
        if last_observed_time is not None:
          self.last_observed_time = last_observed_time
        if state is not None:
          self.state = state

    @property
    def count(self):
        """
        Gets the count of this V1EventSeries.
        Number of occurrences in this series up to the last heartbeat time

        :return: The count of this V1EventSeries.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this V1EventSeries.
        Number of occurrences in this series up to the last heartbeat time

        :param count: The count of this V1EventSeries.
        :type: int
        """

        self._count = count

    @property
    def last_observed_time(self):
        """
        Gets the last_observed_time of this V1EventSeries.
        Time of the last occurrence observed

        :return: The last_observed_time of this V1EventSeries.
        :rtype: datetime
        """
        return self._last_observed_time

    @last_observed_time.setter
    def last_observed_time(self, last_observed_time):
        """
        Sets the last_observed_time of this V1EventSeries.
        Time of the last occurrence observed

        :param last_observed_time: The last_observed_time of this V1EventSeries.
        :type: datetime
        """

        self._last_observed_time = last_observed_time

    @property
    def state(self):
        """
        Gets the state of this V1EventSeries.
        State of this Series: Ongoing or Finished

        :return: The state of this V1EventSeries.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this V1EventSeries.
        State of this Series: Ongoing or Finished

        :param state: The state of this V1EventSeries.
        :type: str
        """

        self._state = state

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, V1EventSeries):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
